Witamy w dokumentacji systemu Bibliografia Publikacji Pracowników
=================================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   edycja_uczelnia
   edycja_wydawnictwo
   edycja_autor
   edycja_jednostka
   wyszukiwanie_redagowanie
   raporty_rankingi
   sloty
   pbn
   import_pracownikow
   zglos_publikacje
   usage_admin
   advanced
   contributing
   faq
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
